summaryrefslogtreecommitdiff
path: root/BaseTools/Source/Python/Common/MigrationUtilities.py
diff options
context:
space:
mode:
Diffstat (limited to 'BaseTools/Source/Python/Common/MigrationUtilities.py')
-rw-r--r--BaseTools/Source/Python/Common/MigrationUtilities.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/BaseTools/Source/Python/Common/MigrationUtilities.py b/BaseTools/Source/Python/Common/MigrationUtilities.py
index b15daa8448..7c69704596 100644
--- a/BaseTools/Source/Python/Common/MigrationUtilities.py
+++ b/BaseTools/Source/Python/Common/MigrationUtilities.py
@@ -360,7 +360,7 @@ def StoreTextFile(TextFile, Content):
# The possible duplication is ensured to be removed.
#
# @param Section Section dictionary indexed by CPU architecture.
# @param Arch CPU architecture: Ia32, X64, Ipf, ARM, Ebc or Common.
# @param Item The Item to be added to section dictionary.
#
def AddToSection(Section, Arch, Item):
@@ -382,7 +382,7 @@ def AddToSection(Section, Arch, Item):
# @retval Section The string content of a section.
#
def GetSection(SectionName, Method, ObjectList):
- SupportedArches = ["common", "Ia32", "X64", "Ipf", "Ebc", "ARM"]
+ SupportedArches = ["common", "Ia32", "X64", "Ipf", "Ebc", "ARM", "AARCH64"]
SectionDict = {}
for Object in ObjectList:
Item = Method(Object)
@@ -360,7 +360,7 @@ def StoreTextFile(TextFile, Content):
#
# @param Section Section dictionary indexed by CPU architecture.
-# @param Arch CPU architecture: Ia32, X64, Ipf, ARM, Ebc or Common.
+# @param Arch CPU architecture: Ia32, X64, Ipf, ARM, AARCH64, Ebc or Common.
# @param Item The Item to be added to section dictionary.
#